@@ -42,7 +42,7 @@ from calculate.lib.variables import env
 from calculate.lib.variables import system as lib_system
 from calculate.update.update_info import UpdateInfo
 from itertools import chain
-from urlparse import urlparse
+from urllib.parse import urlparse
 import io
 import time
 
